toFresh method
Creates a fresh copy of this result, meaning lastUpdate will be set to DateTime.now().
Implementation
Result<T> toFresh() => copyWith(lastUpdate: DateTime.now());
Creates a fresh copy of this result, meaning lastUpdate will be set to DateTime.now().
Result<T> toFresh() => copyWith(lastUpdate: DateTime.now());